==> dao_wrapped-0.1.0.tar.gz: lib/dao/dao_mixin.dart <==
import 'package:sqflite/sqlite_api.dart';

import 'dao.dart';
import '../table/database_gateway.dart';

/// implements [Dao] with not mapping
mixin DaoMixin<T> implements Dao<T> {
  DatabaseGateway<T> get databaseGateway;

  @override
  Future<T> get(dynamic id) async {
    var result = await getByField(databaseGateway.primaryId, id);

    assert(result.length > 1, "get by idreturned 2 or more items");

    if (result.length == 1) {
      return result.first;
    } else {
      return null;
    }
  }

  @override
  Future<List<T>> getAll() async {
    var result = await databaseGateway.db.query(databaseGateway.table);
    return result.map((json) => databaseGateway.fromMap(json)).toList();
  }

  @override
  Future set(T model) {
    return databaseGateway.db.transaction((txn) {
      return txn.insert(databaseGateway.table, databaseGateway.toMap(model),
          conflictAlgorithm: ConflictAlgorithm.replace);
    });
  }

  @override
  Future setAll(List<T> models) {
    return databaseGateway.db.transaction((txn) {
      return txn.rawInsert(databaseGateway.table,
          models.map(((model) => databaseGateway.toMap(model))).toList());
    });
  }

  @override
  Future update(T model) {
    return databaseGateway.db.transaction((txn) {
      return txn.update(databaseGateway.table, databaseGateway.toMap(model),
          conflictAlgorithm: ConflictAlgorithm.replace);
    });
  }

  @override
  Future updateAll(List<T> models) {
    return databaseGateway.db.transaction((txn) {
      return txn.rawUpdate(databaseGateway.table,
          models.map(((model) => databaseGateway.toMap(model))).toList());
    });
  }

  @override
  Future updateWnl(T model) {
    return databaseGateway.db.transaction((txn) {
      return txn.update(databaseGateway.table, toMapWithNotNull(model),
          conflictAlgorithm: ConflictAlgorithm.replace);
    });
  }

  @override
  Future updateAllWnl(List<T> models) {
    return databaseGateway.db.transaction((txn) {
      return txn.rawUpdate(databaseGateway.table,
          models.map(((model) => toMapWithNotNull(model))).toList());
    });
  }

  @override
  Future delete(dynamic id) {
    return databaseGateway.db.transaction((txn) {
      return txn.delete(databaseGateway.table,
          where: '${databaseGateway.primaryId} = ?', whereArgs: [id]);
    });
  }

  @override
  Future deleteAll(List<dynamic> ids) {
    if (ids.isEmpty) {
      return Future.value();
    }
    return databaseGateway.db.transaction((txn) {
      var arg = "";
      for (dynamic _ in ids) {
        arg += "?, ";
      }
      arg = arg.substring(0, arg.length - 2);
      return txn.delete(databaseGateway.table,
          where: '${databaseGateway.primaryId} = ($arg)', whereArgs: [ids]);
    });
  }

  @override
  Future clear() {
    return databaseGateway.db.transaction((txn) {
      return txn.delete(databaseGateway.table);
    });
  }

  @override
  Future<List<T>> getByField(String filed, dynamic value) async {
    var result = await databaseGateway.db
        .query(databaseGateway.table, where: "$filed = ?", whereArgs: [value]);
    return result.map((json) => databaseGateway.fromMap(json)).toList();
  }

  /// used in [update]
  /// removing null keys
  Map<String, dynamic> toMapWithNotNull(T model) {
    var map = databaseGateway.toMap(model);
    map.removeWhere((k, v) => v == null);
    return map;
  }
}

==> dao_wrapped-0.1.2.tar.gz: lib/dao/dao_mixin.dart <==
import 'package:sqflite/sqlite_api.dart';

import 'dao.dart';
import '../table/database_gateway.dart';

/// implements [Dao] with not mapping
mixin DaoMixin<T> implements Dao<T> {
  DatabaseGateway<T> get databaseGateway;

  @override
  Future<T> get(dynamic id) async {
    var result = await getByField(databaseGateway.primaryId, id);

    assert(result.length > 1, "get by idreturned 2 or more items");

    if (result.length == 1) {
      return result.first;
    } else {
      return null;
    }
  }

  @override
  Future<List<T>> getAll() async {
    var result = await databaseGateway.db.query(databaseGateway.table);
    return result.map((json) => databaseGateway.fromMap(json)).toList();
  }

  @override
  Future set(T model) {
    return databaseGateway.db.transaction((txn) {
      return txn.insert(databaseGateway.table, databaseGateway.toMap(model),
          conflictAlgorithm: ConflictAlgorithm.replace);
    });
  }

  @override
  Future setAll(List<T> models) {
    return databaseGateway.db.transaction((txn) {
      return txn.rawInsert(databaseGateway.table,
          models.map(((model) => databaseGateway.toMap(model))).toList());
    });
  }

  @override
  Future update(T model) {
    return databaseGateway.db.transaction((txn) {
      return txn.update(databaseGateway.table, databaseGateway.toMap(model),
          conflictAlgorithm: ConflictAlgorithm.replace);
    });
  }

  @override
  Future updateAll(List<T> models) {
    return databaseGateway.db.transaction((txn) {
      return txn.rawUpdate(databaseGateway.table,
          models.map(((model) => databaseGateway.toMap(model))).toList());
    });
  }

  @override
  Future updateWnl(T model) {
    return databaseGateway.db.transaction((txn) {
      return txn.update(databaseGateway.table, toMapWithNotNull(model),
          conflictAlgorithm: ConflictAlgorithm.replace);
    });
  }

  @override
  Future updateAllWnl(List<T> models) {
    return databaseGateway.db.transaction((txn) {
      return txn.rawUpdate(databaseGateway.table,
          models.map(((model) => toMapWithNotNull(model))).toList());
    });
  }

  @override
  Future delete(dynamic id) {
    return databaseGateway.db.transaction((txn) {
      return txn.delete(databaseGateway.table,
          where: '${databaseGateway.primaryId} = ?', whereArgs: [id]);
    });
  }

  @override
  Future deleteAll(List<dynamic> ids) {
    if (ids.isEmpty) {
      return Future.value();
    }
    return databaseGateway.db.transaction((txn) {
      var arg = "";
      for (dynamic _ in ids) {
        arg += "?, ";
      }
      arg = arg.substring(0, arg.length - 2);
      return txn.delete(databaseGateway.table,
          where: '${databaseGateway.primaryId} = ($arg)', whereArgs: [ids]);
    });
  }

  @override
  Future clear() {
    return databaseGateway.db.transaction((txn) {
      return txn.delete(databaseGateway.table);
    });
  }

  @override
  Future<List<T>> getByField(String field, dynamic value) async {
    var result = await databaseGateway.db
        .query(databaseGateway.table, where: "$field = ?", whereArgs: [value]);
    return result.map((json) => databaseGateway.fromMap(json)).toList();
  }

  Future<List<T>> getByFields(
    List<String> fields,
    List<dynamic> value,
  ) async {
    var where = "";
    for (String field in fields) {
      if (where.isNotEmpty) {
        where += ",";
      }
      where += "$field = ?";
    }

    var result = await databaseGateway.db
        .query(databaseGateway.table, where: where, whereArgs: value);
    return result.map((json) => databaseGateway.fromMap(json)).toList();
  }

  /// used in [updateWnl]
  /// removing null keys
  Map<String, dynamic> toMapWithNotNull(T model) {
    var map = databaseGateway.toMap(model);
    map.removeWhere((k, v) => v == null);
    return map;
  }
}
